==> ec2init-0.11-py3-none-any.whl: ec2init/plans/init/callback_hopsworks.py <==
import logging
import rsa
import base64
from pathlib import Path
from configparser import ConfigParser

import requests
from typing import List, Tuple, Dict, Optional

from ec2init import Procedure
from ec2init.utils.http import HttpUtils
from ec2init.utils.cloud import get_cloud_provider

logger = logging.getLogger(__name__)

PUBLIC_KEY_ENDPOINT = ("GET", "{gateway}/eventsv2/resources/{uid}/instances/{instance_id}/public-key")

class CallbackHopsworks(Procedure):
    def __init__(self, name: str, config: ConfigParser, gateway: str, instance_id:
                 str, node_id: str, instance_type: str, instance_state: str, uid: str,
                 report_endpoint: Tuple[str, str], has_public_ip: bool, user_email: str = None, user_password: str = None,
                 init_stage: str = None, check_file: Path = None, api_key: str = None, cloud_provider: str = "",
                 user_mgm_type: Optional[str] = None) -> None:
        self.name = name
        self.config = config
        self.gateway = gateway
        self.instance_id = instance_id
        self.instance_state = instance_state
        self.uid = uid
        self.user_email = user_email
        self.user_password = user_password
        self.check_file = check_file
        self.report_endpoint = report_endpoint
        self.has_public_ip = has_public_ip
        self.init_stage = init_stage
        self.api_key = api_key
        self.node_id = node_id
        self.instance_type = instance_type
        self.cloud_provider = cloud_provider
        self.user_mgm_type = user_mgm_type

    def pre(self) -> None:
        pass

    def execute(self) -> List[Procedure]:
        logger.info("%s - Starting execution", self.name)

        # Get my public IP
        public_ip = ""
        if self.has_public_ip:
            public_ip = get_cloud_provider(self.cloud_provider).get_public_ip(self.config)
        else:
            logger.debug("%s Skip getting public ip since no public ip is attached", self.name)       
        logger.debug("%s - gotten my public IP: %s", self.name, public_ip)

        data = {"instanceState": self.instance_state, "publicIPv4": public_ip}
        if self.user_email is not None:
            data['email'] = self.user_email
        if self.user_password is not None and self.user_mgm_type is not None and  self.user_mgm_type.upper() != 'MANAGED' :
            publicKey = self._get_public_key()
            data['password'] = base64.b64encode(rsa.encrypt(self.user_password.encode("utf-8"), publicKey)).decode("ascii")
            data['encrypted'] = "true"
        if self.init_stage is not None:
            data['initStage'] = self.init_stage
        if self.node_id is not None:
            data['nodeId'] = self.node_id
        if self.instance_type is not None:
            data['instanceType'] = self.instance_type
        method, url = self.report_endpoint
        headers: Dict[str, str] = {}
        if self.api_key:
            headers = {"x-api-key": self.api_key}

        logger.debug("%s - Doing callback to Hopsworks API with state %s",
                     self.name, self.instance_state)
        url = url.format(gateway=self.gateway, uid=self.uid,
                         instance_id=self.instance_id)
        response = HttpUtils.maybe_api_call(
            self.config, url, method, data=data, headers=headers)
        if self.check_file is not None:
            self.check_file.touch()

        logger.info("%s - Finished my task!", self.name)
        return []
    
    def _get_public_key(self) -> rsa.PublicKey:
        method, url = PUBLIC_KEY_ENDPOINT
        headers: Dict[str, str] = {}
        if self.api_key:
            headers = {"x-api-key": self.api_key}

        url = url.format(gateway=self.gateway, uid=self.uid,
                         instance_id=self.instance_id)
        response = HttpUtils.maybe_api_call(
            self.config, url, method, headers=headers)
        return rsa.PublicKey.load_pkcs1_openssl_pem(base64.b64decode(response["response"]))

    def rollback(self) -> None:
        pass

    def set_stage(self, new_stage : str) -> None:
        self.init_stage = new_stage

==> ec2init-0.19.1-py3-none-any.whl: ec2init/plans/init/callback_hopsworks.py <==
import logging
import rsa
import base64
from pathlib import Path
from configparser import ConfigParser

import requests
from typing import List, Tuple, Dict, Optional

from ec2init import Procedure
from ec2init.utils.http import HttpUtils
from ec2init.utils.cloud import get_cloud_provider

logger = logging.getLogger(__name__)

PUBLIC_KEY_ENDPOINT = ("GET", "{gateway}/eventsv2/resources/{uid}/instances/{instance_id}/public-key")

class CallbackHopsworks(Procedure):
    def __init__(self, name: str, config: ConfigParser, gateway: str, instance_id:
                 str, node_id: str, instance_type: str, instance_state: str, uid: str,
                 report_endpoint: Tuple[str, str], has_public_ip: bool, user_email: str = None, user_password: str = None,
                 init_stage: str = None, check_file: Path = None, api_key: str = None, cloud_provider: str = "",
                 user_mgm_type: Optional[str] = None, create_pwd_user: bool = True) -> None:
        self.name = name
        self.config = config
        self.gateway = gateway
        self.instance_id = instance_id
        self.instance_state = instance_state
        self.uid = uid
        self.user_email = user_email
        self.user_password = user_password
        self.check_file = check_file
        self.report_endpoint = report_endpoint
        self.has_public_ip = has_public_ip
        self.init_stage = init_stage
        self.api_key = api_key
        self.node_id = node_id
        self.instance_type = instance_type
        self.cloud_provider = cloud_provider
        self.user_mgm_type = user_mgm_type
        self.create_pwd_user = create_pwd_user

    def pre(self) -> None:
        pass

    def execute(self) -> List[Procedure]:
        logger.info("%s - Starting execution", self.name)

        # Get my public IP
        public_ip = ""
        if self.has_public_ip:
            public_ip = get_cloud_provider(self.cloud_provider).get_public_ip(self.config)
        else:
            logger.debug("%s Skip getting public ip since no public ip is attached", self.name)       
        logger.debug("%s - gotten my public IP: %s", self.name, public_ip)

        data = {"instanceState": self.instance_state, "publicIPv4": public_ip}
        if self.user_email is not None:
            data['email'] = self.user_email
        if self.user_password is not None and self.user_mgm_type is not None and self.user_mgm_type.upper() != 'MANAGED' and self.create_pwd_user:
            publicKey = self._get_public_key()
            data['password'] = base64.b64encode(rsa.encrypt(self.user_password.encode("utf-8"), publicKey)).decode("ascii")
            data['encrypted'] = "true"
        if self.init_stage is not None:
            data['initStage'] = self.init_stage
        if self.node_id is not None:
            data['nodeId'] = self.node_id
        if self.instance_type is not None:
            data['instanceType'] = self.instance_type
        method, url = self.report_endpoint
        headers: Dict[str, str] = {}
        if self.api_key:
            headers = {"x-api-key": self.api_key}

        logger.debug("%s - Doing callback to Hopsworks API with state %s",
                     self.name, self.instance_state)
        url = url.format(gateway=self.gateway, uid=self.uid,
                         instance_id=self.instance_id)
        response = HttpUtils.maybe_api_call(
            self.config, url, method, data=data, headers=headers)
        if self.check_file is not None:
            self.check_file.touch()

        logger.info("%s - Finished my task!", self.name)
        return []
    
    def _get_public_key(self) -> rsa.PublicKey:
        method, url = PUBLIC_KEY_ENDPOINT
        headers: Dict[str, str] = {}
        if self.api_key:
            headers = {"x-api-key": self.api_key}

        url = url.format(gateway=self.gateway, uid=self.uid,
                         instance_id=self.instance_id)
        response = HttpUtils.maybe_api_call(
            self.config, url, method, headers=headers)
        return rsa.PublicKey.load_pkcs1_openssl_pem(base64.b64decode(response["response"]))

    def rollback(self) -> None:
        pass

    def set_stage(self, new_stage : str) -> None:
        self.init_stage = new_stage
